<?php
// $Id$
/**
 * @file taxonomy_get_service.inc
 * Provides services callbacks for transport retrieval.
 */

/**
 * Access callback.
 */
function taxonomy_get_service_get_access() {
  return user_access('load raw taxonomy data');
}

/**
 * Service callback: load a taxonomy term object.
 *
 * @param $tid
 *  The term id.
 *
 * @return
 *  A taxonomy term object, with in addition to what is returned by
 *  taxonomy_get_term(), the following keys:
 *    - synonyms: a flat array of synonyms.
 *    - parents: an array of parents tids, keyed by tid.
 *    - related: an array array of related term tids, keyed by tid.
 */
function taxonomy_get_service_term_load($tid) {
  $tid = (int) $tid;
  $term = taxonomy_get_term($tid);
  
  $term->synonyms = taxonomy_get_synonyms($tid);
  // We return an array of just tids for both parents and related terms.
  $parent_tids = array_keys(taxonomy_get_parents($tid));
  // A bug in PHP (http://bugs.php.net/bug.php?id=34857) means we could get
  // FALSE if the array is empty, so we have to explicitly set an empty array.
  if (count($parent_tids)) {
    $term->parents = array_combine($parent_tids, $parent_tids);
  }
  else {
    $term->parents = array();
  }

  $related_tids = array_keys(taxonomy_get_related($tid));
  if (count($related_tids)) {
    $term->related = array_combine($related_tids, $related_tids);
  }
  else {
    $term->related = array();
  }
  
  return $term;  
}

/**
 * Service callback: load a taxonomy vocabulary object.
 *
 * @param $vid
 *  The vocabulary id.
 */
function taxonomy_get_service_vocabulary_load($vid) {
  watchdog('taxo get service', "load vocab $vid");
  $vid = (int) $vid;
  $vocabulary = taxonomy_vocabulary_load($vid);
  
  return $vocabulary;  
}
